@@ -17,7 +17,7 @@ class IPPlugin(hildondesktop.HomeItem):
 		self.label.modify_font(pango.FontDescription ("Sans 16"))
 		self.label.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse("#000"))
 		self.label.modify_fg(gtk.STATE_NORMAL, gtk.gdk.color_parse("#fff"))
-		self.label.set_text(self.get_text())
+		self.label.set_text(self.get_ip())
 		self.label.set_padding(15, 10)
 #		self.label.set_padding(-1, -1)
 		self.label.set_size_request(-1,-1)
@@ -31,8 +31,9 @@ class IPPlugin(hildondesktop.HomeItem):
 		# set a timeout to change the images
 		self.timer = gobject.timeout_add(2000, self.update)
 #		print "foreground timer", self.timer
-		self.inbackground = False
 
+    self.background = False
+    
 		self.connect ("background", self.background)
 		self.connect ("foreground", self.foreground)
 
@@ -93,28 +94,22 @@ class IPPlugin(hildondesktop.HomeItem):
 		widget.set_colormap(colormap)
 
 		return False
-	def update(self):
-		self.label.set_markup(self.get_text())
-		self.label.set_size_request(-1,-1)
-		self.set_size_request(-1,-1)
-		#self.timer = gobject.timeout_add(2000, self.update)
-		return not self.inbackground
 
 	def background(self, widget, data=None):
 		#Avoid refresh when applet is in background
 		self.label.set_text("refreshing")
 		self.label.set_size_request(-1,-1)
 		self.set_size_request(-1,-1)
-		self.inbackground = True
+		self.background = True
 		if self.timer != None:
 			gobject.source_remove(self.timer)
 			self.timer = None
 
 	def foreground(self, widget, data=None):
-		self.label.set_markup(self.get_text())
+		self.label.set_text(self.get_ip())
 		self.label.set_size_request(-1,-1)
 		self.set_size_request(-1,-1)
-		self.inbackground = False
+		self.background = False
 		self.timer = gobject.timeout_add(2000, self.update)
 #		print "foreground timer", self.timer
 
@@ -123,7 +118,14 @@ class IPPlugin(hildondesktop.HomeItem):
 		v = gobject.source_remove(self.timer)
 #		print "canceled homeip timeout:", v
 
-	def get_text(self):
+	def update(self):
+		self.label.set_text(self.get_ip())
+		self.label.set_size_request(-1,-1)
+		self.set_size_request(-1,-1)
+		#self.timer = gobject.timeout_add(2000, self.update)
+		return not self.background
+
+	def get_ip(self):
 		#CPU Speed
 		text = "No IP"
 		devs = commands.getoutput("/sbin/ifconfig wlan0")
@@ -134,19 +136,9 @@ class IPPlugin(hildondesktop.HomeItem):
 				sdev = stdev.rsplit(':')
 				sdev2 = sdev[1].rsplit(' ')
 				text= "IP: " + sdev2[0]
-
-		if text == "No IP":
-			devs = commands.getoutput("/sbin/ifconfig ppp0")
-			sdevs = devs.rsplit('\n')
-			for stdev in sdevs:
-				#sdev = re.findall("(\S*)\s*", stdev)
-				if 'inet addr:' in stdev:
-					sdev = stdev.rsplit(':')
-					sdev2 = sdev[1].rsplit(' ')
-					text= "IP: " + sdev2[0]
-
 		return text
 
 def hd_plugin_get_objects():
 	plugin = IPPlugin()
 	return [plugin]
+
